<?php
namespace Sella\Apppago\Controller\Payment;

use Magento\Framework\App\Action\Action;
use Magento\Framework\App\Action\Context;
use Magento\Framework\View\Result\PageFactory;
use Psr\Log\LoggerInterface;
use Sella\Apppago\Model\OrderUpdateStatus;

class ApiOrderUpdateStatus extends Action
{
    protected $resultPageFactory;
    protected $logger;
    protected $orderUpdateStatus;

    public function __construct(
        Context $context,
        PageFactory $resultPageFactory,
        LoggerInterface $logger,
        OrderUpdateStatus $orderUpdateStatus
    ) {
        $this->resultPageFactory = $resultPageFactory;
        $this->logger = $logger;
        $this->orderUpdateStatus = $orderUpdateStatus;
        parent::__construct($context);
    }

    public function execute()
    {

        // $params = $this->getRequest().getParams();
        $json = file_get_contents('php://input');
        $data = json_decode($json, true);

        if (json_last_error() !== JSON_ERROR_NONE) {
            // Gestire l'errore di decodifica JSON
            throw new \Exception("Errore di decodifica JSON: " . json_last_error_msg());
        }

        $merchantId = $data['merchant_order_id'] ?? null;
        $new_status = $data['new_status'] ?? null;
        $contract_number = $data['contract_number'] ?? null;

        $this->orderUpdateStatus->update($merchantId, $new_status, $contract_number);

        if ($new_status === 'completed') {
            $this->_redirect('apppago/payment/success', [
                '_query' => [
                    'result' => "processing",
                    'contract_number' => $contract_number,
                    'checkDigit' => $merchantId
                ]
            ]);
            return;
        } elseif ($new_status === 'refused') {

            $this->_redirect('apppago/payment/success', [
                '_query' => [
                    'result' => "refused",
                    'contract_number' => $contract_number,
                    'checkDigit' => $merchantId
                ]
            ]);
        }
    }
}
