<?php
namespace Sella\Apppago\Controller\Payment;

use Magento\Framework\App\Action\Action;
use Magento\Framework\App\Action\Context;
use Magento\Framework\View\Result\PageFactory;
use Magento\Sales\Api\OrderRepositoryInterface;

class Success extends Action
{
    protected $resultPageFactory;
    protected $orderRepository;

    public function __construct(
        Context $context,
        PageFactory $resultPageFactory,
        OrderRepositoryInterface $orderRepository
    ) {
        $this->resultPageFactory = $resultPageFactory;
        $this->orderRepository = $orderRepository;
        parent::__construct($context);
    }

    public function execute()
    {
        $orderId = $this->getRequest()->getParam('checkDigit');
        $result = $this->getRequest()->getParam('result');

        $order = $this->orderRepository->get($orderId);

        $data = [
            'result' => $result,
            'merchantTx' => $this->getRequest()->getParam('merchantTx'),
            'contract_number' => $this->getRequest()->getParam('contract_number'),
            'checkDigit' => $this->getRequest()->getParam('checkDigit')];

        if($result === 'ERROR') {
            $errorCode = $this->getRequest()->getParam('error_code');
            $errorDesc = $this->getRequest()->getParam('error_desc');
            $order->addStatusHistoryComment('Pagamento fallito. Codice errore: ' . $errorCode . '. Descrizione errore: ' . $errorDesc);
            $order->setState(\Magento\Sales\Model\Order::STATE_CANCELED, true);
            $order->setStatus(\Magento\Sales\Model\Order::STATE_CANCELED);
            $this->orderRepository->save($order);

            $data['error_code'] = $errorCode;
            $data['error_desc'] = $errorDesc;
        } else {
            $order->setState(\Magento\Sales\Model\Order::STATE_PROCESSING, true);
            $order->setStatus(\Magento\Sales\Model\Order::STATE_PROCESSING);
            $this->orderRepository->save($order);
        }
        
        $resultPage = $this->resultPageFactory->create();
        $block = $resultPage->getLayout()->getBlock('payment.success');
        $block->setData($data);
        $block->setData('order', $order);
        
        return $resultPage;
    }
}
