<?php

namespace Sella\Apppago\Model;

use Sella\Apppago\Service\OrderService;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Checkout\Model\Session as CheckoutSession;
use Magento\Framework\Exception\LocalizedException;
// ScopeInterface 
use Magento\Store\Model\ScopeInterface;


class AddOrder
{
    protected $orderService;
    protected $scopeConfigInterface;
    protected $checkoutSession;

    public function __construct(
        OrderService $orderService,
        ScopeConfigInterface $scopeConfigInterface,
        CheckoutSession $checkoutSession
    ) {
        $this->orderService = $orderService;
        $this->scopeConfigInterface = $scopeConfigInterface;
        $this->checkoutSession = $checkoutSession;
    }

    public function getConfigValue($field)
    {
        return $this->scopeConfigInterface->getValue(
            'payment/general/' . $field,
            ScopeInterface::SCOPE_STORE
        );
    }

    public function createOrder($data): string
    {
        try {

            $order = $this->orderService->createOrder($data);
            $order->setState("new")->setStatus("pending");

            $orderId = $order->getId();

            $quote = $this->checkoutSession->getQuote();

            $olMerchantTrxId = substr(str_shuffle("0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"), 0, 5);

            $installments_type = $this->getConfigValue('installments_type');
            $installments_number = null;

            if ($installments_type) {
                switch ($installments_type) {
                    case 'fixed':
                        $installments_number = $this->getConfigValue('fixed_installment');
                        break;
                    case 'range':
                        $installments_number = $this->getConfigValue('range_min_installment') . '-' . $this->getConfigValue('range_max_installment');
                        break;
                    case 'select':
                        $installments_number = $this->getConfigValue('select_installment');
                        break;
                    default:
                        break;
                }
            }

            //get total amount of current order
            $total = $order->getGrandTotal();


            // value merchantId from config
            $merchantId = $this->getConfigValue('merchant_id');

            $billingAddress = $order->getBillingAddress();

            $firstname = $billingAddress->getFirstname();
            $lastname = $billingAddress->getLastname();

            $callbackUrl = "http://localhost/rest/default/V1/callback";

            $body = [
                "olMerchantTrxId" => $olMerchantTrxId,
                "merchantId" => $this->scopeConfigInterface->getValue('payment/general/' . 'merchant_code', ScopeInterface::SCOPE_STORE) ? $this->scopeConfigInterface->getValue('payment/general/' . 'merchant_code', ScopeInterface::SCOPE_STORE) : 'no merchantId',
                "loanTotalAmount" => $total ? $total : 'no loanTotalAmount',
                "installmentsNumber" => "",
                "taxCode" => $data->getVatMethod() ? strtoupper($data->getVatMethod()) : 'no taxCode',
                "merchantRedirect" => $callbackUrl,
                "firstname" => $firstname ? $firstname : 'no firstname',
                "lastname" => $lastname ? $lastname : 'no lastname',
                "residenceAddress" => $billingAddress->getStreetLine(1) ? $billingAddress->getStreetLine(1) : 'no residenceAddress',
                "residenceCity" => $billingAddress->getCity() ? $billingAddress->getCity() : 'no residenceCity',
                "residenceState" => $billingAddress->getRegion() ? $billingAddress->getRegion() : 'no residenceState',
                "residencePostalCode" => $billingAddress->getPostcode() ? $billingAddress->getPostcode() : 'no residencePostalCode',
                "email" => $billingAddress->getEmail() ? $billingAddress->getEmail() : 'no email',
                "phone" => $billingAddress->getTelephone() ? $billingAddress->getTelephone() : 'no phone',
                "merchant_order_id" => '' . $orderId . '',
            ];

            $redirectUrl = $this->orderService->callApi($body);
            return $redirectUrl;
        } catch (\Exception $e) {
            throw new LocalizedException(
                __("Error placing the order: " . $e->getMessage())
            );
        }
    }
}