<?php

namespace Sella\Apppago\Model;

use Sella\Apppago\Service\CallbackStatusService;
use Magento\Sales\Api\OrderRepositoryInterface;
use Psr\Log\LoggerInterface;
use Sella\Apppago\Model\UpdateResultFactory;
use Sella\Apppago\Api\CallbackOrderStatusInterface;

class CallbackOrderUpdateStatus implements CallbackOrderStatusInterface {
    protected $callbackStatusService;
    protected $orderRepository;
    protected $logger;
    protected $updateResultFactory;
    
    public function __construct(
        CallbackStatusService $callbackStatusService,
        OrderRepositoryInterface $orderRepository,
        LoggerInterface $logger,
        UpdateResultFactory $updateResultFactory
    ) {
        $this->callbackStatusService = $callbackStatusService;
        $this->orderRepository = $orderRepository;
        $this->logger = $logger;
        $this->updateResultFactory = $updateResultFactory;
    }

    public function getOrderStatus($result, $merchantTx, $contract_number, $checkDigit): void {

        if($result == 'OK') {
            $status = 'awaiting-payment';
        } elseif($result == 'ERROR') {
            $status = 'canceled';
        }
        
        try {
            $data = [
                'new_status' => $status,
                'olMerchantTrxId' => $merchantTx,
                'contract_number' => $contract_number,
                'merchant_order_id' => $checkDigit
            ];
            $this->callbackStatusService->updateOrderStatus($data);
            $order = $this->orderRepository->get($checkDigit);
            $order->setState($status, true);
            $order->setStatus($status);
            $this->orderRepository->save($order);
        } catch (\Exception $e) {
            $this->logger->critical($e->getMessage());
        }

        $response = $this->updateResultFactory->create();
        $response->setOrderId($checkDigit);
        $response->setStatus($status);
        $response->setSuccess(true);

        $redirectUrl = `http://localhost/apppago/payment/apiOrderUpdateStatus?result=${result}&merchantTx=${merchantTx}&contract_number=${contract_number}&checkDigit=${checkDigit}`;
        header('Location: ' . $redirectUrl);
        exit;
    }
}