<?php

namespace Sella\Apppago\Observer;

use Magento\Framework\Event\ObserverInterface;
use Magento\Config\Model\Config;
use Magento\Store\Model\ScopeInterface;
use Magento\Framework\App\Config\ScopeConfigInterface;
use GuzzleHttp\Client;
use Magento\Framework\App\Config\Storage\WriterInterface;


class SaveConfigAndPostToApi implements ObserverInterface
{
    protected $_configModel;
    protected $scopeConfig;
    protected $httpClient;
    protected $configWriter;

    public function __construct(Config $configModel, ScopeConfigInterface $scopeConfig, WriterInterface $configWriter)
    {
        $this->_configModel = $configModel;
        $this->scopeConfig = $scopeConfig;
        $this->httpClient = new Client();
        $this->configWriter = $configWriter;
    }

    public function execute(\Magento\Framework\Event\Observer $observer)
    {

        $merchantCode = $this->scopeConfig->getValue('payment/general/merchant_code', ScopeInterface::SCOPE_STORE);
        $vat = $this->scopeConfig->getValue('payment/general/vat', ScopeInterface::SCOPE_STORE);
        $max_amount = $this->scopeConfig->getValue('payment/general/max_amount', ScopeInterface::SCOPE_STORE);
        $min_amount = $this->scopeConfig->getValue('payment/general/min_amount', ScopeInterface::SCOPE_STORE);

        $gen_api_key = bin2hex(random_bytes(16));
        // setValue api_key in config
        $this->configWriter->save('payment/general/api_key', $gen_api_key, ScopeConfigInterface::SCOPE_TYPE_DEFAULT, 0);
        // get gen_api_key from config
        $api_key = $this->scopeConfig->getValue('payment/general/api_key', ScopeInterface::SCOPE_STORE);

        $permit_iban = $this->scopeConfig->getValue('payment/general/permit_iban', ScopeInterface::SCOPE_STORE);
        $is_company = $this->scopeConfig->getValue('payment/general/isCompany', ScopeInterface::SCOPE_STORE);
        $installments_type = $this->scopeConfig->getValue('payment/general/installments_type', ScopeInterface::SCOPE_STORE);
        $fixed_installment = "";
        $range_min_installment = "";
        $range_max_installment = "";
        $select_installment = "";

        if ($installments_type == 'fixed') {
            $fixed_installment = $this->scopeConfig->getValue('payment/general/fixed_installment', ScopeInterface::SCOPE_STORE);
        } else if ($installments_type == 'range') {
            $range_min_installment = $this->scopeConfig->getValue('payment/general/range_min_installment', ScopeInterface::SCOPE_STORE);
            $range_max_installment = $this->scopeConfig->getValue('payment/general/range_max_installment', ScopeInterface::SCOPE_STORE);
        } else if ($installments_type == 'select') {
            $select_installment = $this->scopeConfig->getValue('payment/general/select_installment', ScopeInterface::SCOPE_STORE);
        }


        $postFields = [
            //change for updates
            'platform' => 'magento',
            'version' => '1.2.5',
            "host" => $_SERVER['HTTP_HOST'],
            'merchant_code' => $merchantCode,
            'vat' => $vat,
            'api_key' => $gen_api_key,
            'max_amount' => $max_amount,
            'min_amount' => $min_amount,
            'installments_type' => $installments_type,
            'fixed_installments_number' => $fixed_installment,
            'range_installments_min' => $range_min_installment,
            'range_installments_max' => $range_max_installment,
            'select_installments_list' => $select_installment,
            'iban_allowed' => $permit_iban == NULL ? "0" : "1",
            'company_allowed' => $is_company == NULL ? "0" : "1",
        ];

        $options = [
            'http' => [
                'header' => "Content-type: application/x-www-form-urlencoded\r\n",
                'method' => 'POST',
                'content' => http_build_query($postFields),
            ],
        ];
        $context = stream_context_create($options);
        //TODO change url to prod or test
        $result = file_get_contents('https://secure.sellapersonalcredit.it/SPCPlugAppPago/api/config', false, $context);


        if ($result === FALSE) {
            echo "Errore nella richiesta HTTP.";
        } else {
            echo "Risposta ottenuta: " . $result;
        }
    }
}
