<?php
namespace Sella\Apppago\Service;

use Psr\Log\LoggerInterface;
use Magento\Framework\HTTP\ClientInterface;
use Magento\Store\Model\ScopeInterface;
use Magento\Framework\App\Config\ScopeConfigInterface;


class CallbackStatusService
{
    protected $logger;

    protected $scopeConfig;
    protected $httpClient;

    public function __construct(
        LoggerInterface $logger,
        ClientInterface $httpClient,
        ScopeConfigInterface $scopeConfig
    ) {
        $this->logger = $logger;
        $this->httpClient = $httpClient;
        $this->scopeConfig = $scopeConfig;
    }

    public function updateOrderStatus($data)
    {
        $this->logger->debug("Start callApi method");

        try {
            $url = "";
            if ($this->scopeConfig->getValue('payment/general/testmode', ScopeInterface::SCOPE_STORE) == 1) {
                $url = "https://sandbox.sellapersonalcredit.it/SPCPlugAppPago/api/order/update/status";
            } else {
                $url = "https://secure.sellapersonalcredit.it/SPCPlugAppPago/api/order/update/status";
            }

            $this->httpClient->post($url, $data);
            $response = $this->httpClient->getBody();

            $responseDecode = json_decode($response, true);

            // if status is "ok" logger ok
            if ($responseDecode['status'] == 'ok') {
                $this->logger->info("HTTP Client POST response, status: " . $responseDecode['status']);
            } else {
                $this->logger->error("HTTP Client POST response, status: " . $responseDecode['status']);
            }

        } catch (\Exception $e) {
            $this->logger->error("HTTP Client POST response, error" . $e->getMessage());
        }
        $this->logger->debug("End callApi method");
    }

}
