<?php
namespace Sella\Apppago\Service;

use Magento\Quote\Api\CartManagementInterface;
use Magento\Quote\Api\CartRepositoryInterface;
use Magento\Sales\Api\OrderRepositoryInterface;
use Psr\Log\LoggerInterface;
use Magento\Framework\Exception\LocalizedException;
use Magento\Sales\Model\Order\StatusFactory;
use Magento\Framework\HTTP\ClientInterface;
use Magento\Store\Model\ScopeInterface;
use Magento\Framework\App\Config\ScopeConfigInterface;

class OrderService implements \Sella\Apppago\Api\AddOrderInterface
{
    protected $cartManagement;

    protected $scopeConfig;
    protected $cartRepository;
    protected $orderRepository;
    protected $logger;
    protected $statusFactory;
    protected $httpClient;

    public function __construct(
        CartManagementInterface $cartManagement,
        CartRepositoryInterface $cartRepository,
        OrderRepositoryInterface $orderRepository,
        LoggerInterface $logger,
        StatusFactory $statusFactory,
        ScopeConfigInterface $scopeConfig,
        ClientInterface $httpClient
    ) {
        $this->cartManagement = $cartManagement;
        $this->cartRepository = $cartRepository;
        $this->orderRepository = $orderRepository;
        $this->logger = $logger;
        $this->statusFactory = $statusFactory;
        $this->httpClient = $httpClient;
        $this->scopeConfig = $scopeConfig;
    }

    public function createOrder($data): \Magento\Sales\Api\Data\OrderInterface
    {
        $this->logger->debug("Start createOrder method");
        // Data validation

        $cartId = $data->getCartId();
        $paymentMethod = $data->getPaymentMethod();

        // Debug log per cartId e paymentMethod
        $this->logger->debug("cartId: " . var_export($cartId, true));
        $this->logger->debug("paymentMethod: " . var_export($paymentMethod, true));

        if (!$cartId || !$paymentMethod) {
            throw new \Exception("Missing data");
        }

        $this->logger->debug("Before retrieving the cart object");
        $cart = $this->cartRepository->get($cartId);
        $this->logger->debug("After retrieving the cart object");
        $cart->getPayment()->setMethod($paymentMethod);

        $this->cartRepository->save($cart);

        $orderId = $this->cartManagement->placeOrder($cartId, null);

        $this->logger->debug("After placeOrder");

        $order = $this->orderRepository->get($orderId);

        $this->logger->debug("order here");

        $status = $this->statusFactory->create()->load('awaiting_payment', 'status');

        if (!$status->getId()) {
            $status = $this->statusFactory->create();
            $status->setData([
                'status' => 'awaiting_payment',
                'label' => 'Awaiting Payment',
            ]);
            $status->save();
            $status->assignState(\Magento\Sales\Model\Order::STATE_NEW, false, true);
        }

        $order->setState(\Magento\Sales\Model\Order::STATE_NEW);
        $order->setStatus('awaiting_payment');
        $this->orderRepository->save($order);
        return $order;

    }

    public function callApi($body)
    {
        $this->logger->debug("Start callApi method");

        try {
            $url = "";
            if ($this->scopeConfig->getValue('payment/general/testmode', ScopeInterface::SCOPE_STORE) == 1) {
                $url = 'https://sandbox.sellapersonalcredit.it/SPCPlugAppPago/api/order';
            } else {
                $url = 'https://secure.sellapersonalcredit.it/SPCPlugAppPago/api/order';
            }

            $this->httpClient->post($url, $body);
            $response = $this->httpClient->getBody();

            $responseDecode = json_decode($response, true);

            if (isset($responseDecode['redirectUrl'])) {
                return $responseDecode['redirectUrl'];
            } else {
                $this->logger->debug("Error redirectUrl not found");
                return null;
            }
        } catch (\Exception $e) {
            $this->logger->error("HTTP Client POST response, error" . $e->getMessage());
            throw new LocalizedException(
                __("API call failed: " . $e->getMessage())
            );
        }
        $this->logger->debug("End callApi method");
    }
}
